from django.test import TestCase
from django.test import Client
from django.core.urlresolvers import reverse

# Create your tests here.
class SlothTestCase(TestCase):
	fixtures = ['arrogant.json']
	def setUp(self):
		self.client = Client()

	def test_clist(self):
		response = self.client.get(reverse('arrogant:jlist')+"?location=台南市東區&start=1")
		self.assertEqual(response.json(), [{'pk': 754, 'model': 'arrogant.job', 'fields': {'實習時段': '暑期實習、學期實習、學年實習', 'job': '台南遠百店-涮乃葉 內外場計時人員(實習', '休假制度': '排休, 輪休', '工作地點': '台南市東區 前鋒路210號四樓(大遠百', '工作時間': '日班, 中班, 晚班, 假日班, 輪', '身份類別': '一般求職者／日間就學中', '薪資': '時薪\xa0133至150', '職缺更新': '2017/4/19', '職務類別': '餐飲服務人員、餐廚助手', '工作說明': '「涮乃葉」為雲雀在台開幕之新品牌歡迎您加', '聯絡人員': '林店長', 'fromWitchWeb': '1111', 'avatar': 'maid_BwdsckP.png', '地區': '台南市東區', '需求人數': '不限', 'url': 'http://www.1111.com.tw/job-bank/job-description.asp?eNo=79117525&agent=internships', '工作經驗': '不拘', '學歷限制': '不拘', '工作性質': '兼職、企業實習', 'company': 1006, '科系限制': '不拘', '到職日期': '不限'}}])

	def test_cvalue(self):
		response = self.client.get(reverse('arrogant:jvalue')+'?id=754')
		self.assertEqual(response.json(), {'工作性質': '兼職、企業實習', 'avatar': '/media/maid_BwdsckP.png', '工作時間': '日班, 中班, 晚班, 假日班, 輪', '職務類別': '餐飲服務人員、餐廚助手', '職缺更新': '2017/4/19', 'id': 754, '實習時段': '暑期實習、學期實習、學年實習', 'job': '台南遠百店-涮乃葉 內外場計時人員(實習', '工作說明': '「涮乃葉」為雲雀在台開幕之新品牌歡迎您加', '身份類別': '一般求職者／日間就學中', '工作地點': '台南市東區 前鋒路210號四樓(大遠百', '地區': '台南市東區', '工作經驗': '不拘', '科系限制': '不拘', '到職日期': '不限', 'url': 'http://www.1111.com.tw/job-bank/job-description.asp?eNo=79117525&agent=internships', '聯絡人員': '林店長', '薪資': '時薪\xa0133至150', '學歷限制': '不拘', '需求人數': '不限', 'company': '雲雀國際股份有限公司', '休假制度': '排休, 輪休', 'fromWitchWeb': '1111'})

	def test_search(self):
		response = self.client.get(reverse('arrogant:recommendJvalue')+"?school=nchu&dept=U56&degree=3")
		self.assertEqual(response.status_code, 200)

	def test_comment(self):
		response = self.client.get(reverse('arrogant:comment')+"?id=754&start=1")		
		self.assertEqual(response.json(), [{"model":"arrogant.comment","pk":1,"fields":{"Job":754,"create":"2017-04-24T11:54:42Z","raw":"測試測試"}},{"model":"arrogant.comment","pk":2,"fields":{"Job":754,"create":"2017-04-24T14:13:08.788Z","raw":"這是測試"}},{"model":"arrogant.comment","pk":3,"fields":{"Job":754,"create":"2017-04-24T14:19:11.154Z","raw":"測試第三次XD"}}])


from django.http import JsonResponse, Http404
from django.shortcuts import render
from djangoApiDec.djangoApiDec import queryString_required, date_proc, queryString_required_ClassVersion
from django.forms.models import model_to_dict
from arrogant.models import *
from django.views import View
from django.core import serializers
import json, datetime

@queryString_required(['school', 'dept', 'degree'])
def recommendJvalue(request):
    try:
        j = Job.objects.all()[0]
        result = model_to_dict(j)
        result['avatar'] = result['avatar'].url if result['avatar'] else None
        result['company'] = j.company.company
        return JsonResponse(result, safe=False)
    except Exception as e:
        raise e

@queryString_required(['id'])
def jvalue(request):
    try:
        j = Job.objects.get(id=request.GET['id'])
        result = model_to_dict(j)
        result['avatar'] = result['avatar'].url if result['avatar'] else None
        result['company'] = j.company.company
        return JsonResponse(result, safe=False)
    except Exception as e:
        raise e

# 這邊應該要改成school當作參數，後端把學校轉成縣市名稱，然後用縣市去查詢該縣市的職缺
@queryString_required(['location', 'start'])
def jlist(request):
    start = int(request.GET['start']) - 1
    result = Job.objects.filter(地區=request.GET['location'])[start:start+15]
    return JsonResponse(json.loads(serializers.serialize('json', list(result))), safe=False)

# 顯示特定一門課程的留言評論
@queryString_required(['id', 'start'])
def comment(request):
    try:
        start = int(request.GET['start']) - 1
        j = Job.objects.get(id=request.GET['id'])
        result = j.comment_set.all()[start:start+15]
        return JsonResponse(json.loads(serializers.serialize('json', list(result))), safe=False)
    except Exception as e:
        print('job not found ' + str(e))



# -*- coding: utf-8 -*-
from django.conf.urls import url
from arrogant import views

urlpatterns = [
  url(r'^get/recommendJvalue$', views.recommendJvalue, name='recommendJvalue'),
  url(r'^get/jvalue$', views.jvalue, name='jvalue'),
  url(r'^get/jlist$', views.jlist, name='jlist'),
  url(r'^get/comment$', views.comment, name='comment'),
]



from django.db import models
import datetime
# 要取得會員的model要這樣寫
from userper import Userper
User = Userper('login.stufinite.faith')

# Create your models here.
class Company(models.Model):
	company = models.CharField(max_length=20)
	def __str__(self):
		return self.company

class Job(models.Model):
	"""docstring for Job"""
	avatar = models.ImageField(default='politician.png') # 大頭貼照片
	職務類別 = models.CharField(max_length=20, null=True)
	學歷限制 = models.CharField(max_length=20, null=True)
	job = models.CharField(max_length=35)
	聯絡人員 = models.CharField(max_length=20, null=True)
	需求人數 = models.CharField(max_length=20, null=True)
	工作經驗 = models.CharField(max_length=20, null=True)
	到職日期 = models.CharField(max_length=20, null=True)
	薪資 = models.CharField(max_length=20, null=True)
	地區 = models.CharField(max_length=20, null=True)
	科系限制 = models.CharField(max_length=20, null=True)
	工作時間 = models.CharField(max_length=35, null=True)
	休假制度 = models.CharField(max_length=20, null=True)
	工作地點 = models.CharField(max_length=20, null=True)
	實習時段 = models.CharField(max_length=20, null=True)
	職缺更新 = models.CharField(max_length=20, null=True)
	工作性質 = models.CharField(max_length=20, null=True)
	company = models.ForeignKey(Company)
	url = models.CharField(max_length=100)
	工作說明 = models.CharField(max_length=100, null=True)
	身份類別 = models.CharField(max_length=20, null=True)
	fromWitchWeb = models.CharField(max_length=10, default='1111')
	def __str__(self):
		return self.job

class Comment(models.Model):
	Job = models.ForeignKey(Job)
	author = User
	create = models.DateTimeField(default=datetime.datetime.now)
	raw = models.CharField(max_length=500)
	def __str__(self):
		return self.raw



from distutils.core import setup

setup(
    name = 'arrogant',
    packages = ['arrogant'],
    version = '1.5',
    description = 'An API for 企業徵才.',
    author = 'davidtnfsh',
    author_email = 'davidtnfsh@gmail.com',
    url = 'https://github.com/Stufinite/arrogant',
    download_url = 'https://github.com/Stufinite/arrogant/archive/v1.5.tar.gz',
    keywords = ['arrogant', 'campass'],
    classifiers = [],
    license='GPL3.0',
    install_requires=[
        'djangoApiDec',
    ],
    zip_safe=True,
)
